@@ -38,10 +38,26 @@ extern "C" {
 #define OQS_SIG_alg_dilithium_3 "Dilithium3"
 /** Algorithm identifier for Dilithium5 */
 #define OQS_SIG_alg_dilithium_5 "Dilithium5"
+/** Algorithm identifier for ML-DSA-44-ipd */
+#define OQS_SIG_alg_ml_dsa_44_ipd "ML-DSA-44-ipd"
+/** Algorithm identifier for ML-DSA-44 SIG. */
+#define OQS_SIG_alg_ml_dsa_44 "ML-DSA-44"
+/** Algorithm identifier for ML-DSA-65-ipd */
+#define OQS_SIG_alg_ml_dsa_65_ipd "ML-DSA-65-ipd"
+/** Algorithm identifier for ML-DSA-65 SIG. */
+#define OQS_SIG_alg_ml_dsa_65 "ML-DSA-65"
+/** Algorithm identifier for ML-DSA-87-ipd */
+#define OQS_SIG_alg_ml_dsa_87_ipd "ML-DSA-87-ipd"
+/** Algorithm identifier for ML-DSA-87 SIG. */
+#define OQS_SIG_alg_ml_dsa_87 "ML-DSA-87"
 /** Algorithm identifier for Falcon-512 */
 #define OQS_SIG_alg_falcon_512 "Falcon-512"
 /** Algorithm identifier for Falcon-1024 */
 #define OQS_SIG_alg_falcon_1024 "Falcon-1024"
+/** Algorithm identifier for Falcon-padded-512 */
+#define OQS_SIG_alg_falcon_padded_512 "Falcon-padded-512"
+/** Algorithm identifier for Falcon-padded-1024 */
+#define OQS_SIG_alg_falcon_padded_1024 "Falcon-padded-1024"
 /** Algorithm identifier for SPHINCS+-SHA2-128f-simple */
 #define OQS_SIG_alg_sphincs_sha2_128f_simple "SPHINCS+-SHA2-128f-simple"
 /** Algorithm identifier for SPHINCS+-SHA2-128s-simple */
@@ -69,8 +85,9 @@ extern "C" {
 ///// OQS_COPY_FROM_UPSTREAM_FRAGMENT_ALG_IDENTIFIER_END
 // EDIT-WHEN-ADDING-SIG
 ///// OQS_COPY_FROM_UPSTREAM_FRAGMENT_ALGS_LENGTH_START
+
 /** Number of algorithm identifiers above. */
-#define OQS_SIG_algs_length 17
+#define OQS_SIG_algs_length 25
 ///// OQS_COPY_FROM_UPSTREAM_FRAGMENT_ALGS_LENGTH_END
 
 /**
@@ -240,6 +257,9 @@ OQS_API void OQS_SIG_free(OQS_SIG *sig);
 #ifdef OQS_ENABLE_SIG_DILITHIUM
 #include <oqs/sig_dilithium.h>
 #endif /* OQS_ENABLE_SIG_DILITHIUM */
+#ifdef OQS_ENABLE_SIG_ML_DSA
+#include <oqs/sig_ml_dsa.h>
+#endif /* OQS_ENABLE_SIG_ML_DSA */
 #ifdef OQS_ENABLE_SIG_FALCON
 #include <oqs/sig_falcon.h>
 #endif /* OQS_ENABLE_SIG_FALCON */
